@@ -25,7 +25,7 @@
 
 constraints.checkRequired <- function(constraint, value) {
   
-  if (!(constraint && (is.null(value) | 
+  if (!(isTRUE(constraint) && (is.null(value) | 
                        isTRUE(value == "undefined") | 
                        exists(deparse(substitute(value)))))) {
     return(TRUE)
